/**
 * @file clock.c
 *
 * @brief This file contains timing routines for the USBlini firmware
 *        project.
 *
 * @author Thomas Fischl (https://www.fischl.de/contact.html)
 * @copyright (c) 2021 Thomas Fischl
 * 
 * This file is part of the USBlini firmware project and is copyrighted by the
 * authors listed above. It is free for private or educational non-commercial use
 * (for a commercial license please contact the authors). It may not be
 * redistributed without the prior written consent of the authors.
 *
 * It is provided "as is" without warranty of any kind, either express or implied,
 * including without limitation any implied warranties of condition, uninterrupted
 * use, merchantability, fitness for a particular purpose, or non-infringement. In
 * no event shall the authors be liable for any direct or indirect damages arising
 * in any way out of the use of it.
 *
 */

#include "usblini.h"
#include "clock.h"

volatile uint16_t msticker = 0;

/**
 * @brief Initialize timer module
 */
void clock_init(void) {
    
    // enable timer 1 with 1:8 -> 1.5MHz
    T1CON = 0x31;
    TMR1IE = 1;
}

/**
 * @brief Get milliseconds ticker
 * @return Ticker value
 */
uint16_t clock_getMSTicker(void) {
    TMR1IE = 0;
    uint16_t temp = msticker;
    TMR1IE = 1;
    return temp;
}


/**
 * @brief Timer interrupt routine
 */
inline void clock_isr(void) {
    TMR1 = 0xffff - 1500 + TMR_RELOAD_CORRECTION; // reload for 1 kHz
    
    msticker++;
}
