/**
 * @file linmaster.h
 *
 * @brief This file contains definitons for LIN bus master functions for the USBlini
 *        firmware project.
 *
 * @author Thomas Fischl (https://www.fischl.de/contact.html)
 * @copyright (c) 2021 Thomas Fischl
 * 
 * This file is part of the USBlini firmware project and is copyrighted by the
 * authors listed above. It is free for private or educational non-commercial use
 * (for a commercial license please contact the authors). It may not be
 * redistributed without the prior written consent of the authors.
 *
 * It is provided "as is" without warranty of any kind, either express or implied,
 * including without limitation any implied warranties of condition, uninterrupted
 * use, merchantability, fitness for a particular purpose, or non-infringement. In
 * no event shall the authors be liable for any direct or indirect damages arising
 * in any way out of the use of it.
 *
 */
#ifndef LINMASTER_H
#define	LINMASTER_H

void linmaster_sendHeader(uint8_t id);
void linmaster_sendFrame(uint8_t id, uint8_t * data, uint8_t length, uint8_t checksum_mode, uint8_t source);
uint8_t linmaster_requestFrame(uint8_t id, uint8_t * responsedata);
void linmaster_setSequence(uint16_t period, uint16_t frametime, uint8_t * ids, uint8_t length);
void linmaster_clearSequence(void);
void linmaster_process(void);
inline void linmaster_timer_isr(void);



#endif	/* LINMASTER_H */

