/**
 * @file usb_descr.h
 *
 * @brief This file contains the USB descriptor for the USBlini
 *        firmware project.
 *
 * @author Thomas Fischl (https://www.fischl.de/contact.html)
 * @copyright (c) 2021 Thomas Fischl
 * 
 * This file is part of the USBlini firmware project and is copyrighted by the
 * authors listed above. It is free for private or educational non-commercial use
 * (for a commercial license please contact the authors). It may not be
 * redistributed without the prior written consent of the authors.
 *
 * It is provided "as is" without warranty of any kind, either express or implied,
 * including without limitation any implied warranties of condition, uninterrupted
 * use, merchantability, fitness for a particular purpose, or non-infringement. In
 * no event shall the authors be liable for any direct or indirect damages arising
 * in any way out of the use of it.
 *
 */

#ifndef _USB_DESCR_
#define _USB_DESCR_

#define DESCR_DEVICE 0x01
#define DESCR_CONFIG 0x02
#define DESCR_STRING 0x03
#define DESCR_INTERFACE 0x04
#define DESCR_ENDPOINT 0x05
#define DESCR_HID 0x21
#define DESCR_HID_REPORT 0x22

const unsigned char usb_dev_desc[] = {
    18,
    0x01,
    0x00, 0x02,
    0x00, // Class code
    0x00,
    0x00,
    0x08, // max packet size
    0xd8, 0x04, // vendor
    0x70, 0xe8, // product
    0x00, 0x01, // device release
    0x01, // manuf string
    0x02, // product string
    0x00, // serial number string (if number available, index 3 is set on the fly)
    0x01
};

const unsigned char usb_config_desc[] = {
    0x09, /* bLength: Configuation Descriptor size */
    0x02, /* bDescriptorType: Configuration */
    9 + 9 + 7 + 7, /* wTotalLength:no of returned bytes */
    0x00,
    0x01, /* bNumInterfaces: 1 interface */
    0x01, /* bConfigurationValue: Configuration value */
    0x00, /* iConfiguration: Index of string descriptor describing the configuration */
    0x80, /* bmAttributes: bus powered */
    50, /* MaxPower 100 mA */
    /*Interface Descriptor*/
    0x09, /* bLength: Interface Descriptor size */
    0x04, /* bDescriptorType: Interface */
    /* Interface descriptor type */
    0x00, /* bInterfaceNumber: Number of Interface */
    0x00, /* bAlternateSetting: Alternate setting */
    0x02, /* bNumEndpoints */
    0x00, /* bInterfaceClass*/
    0x00, /* bInterfaceSubClass */
    0x00, /* bInterfaceProtocol */
    0x00, /* iInterface: */    
    /*Endpoint 1 Descriptor*/
    0x07,   /* bLength: Endpoint Descriptor size */
    DESCR_ENDPOINT,   /* bDescriptorType: Endpoint */
    0x81,   /* bEndpointAddress: (IN1) */
    0x03,   /* bmAttributes: Interrupt */
    0x40,   /* wMaxPacketSize: */
    0x00,
    0x01,    /* bInterval: 1 ms */    
    /*Endpoint 2 Descriptor*/
    0x07,   /* bLength: Endpoint Descriptor size */
    DESCR_ENDPOINT,   /* bDescriptorType: Endpoint */
    0x82,   /* bEndpointAddress: (IN2) */
    0x03,   /* bmAttributes: Interrupt */
    0x40,   /* wMaxPacketSize: */
    0x00,
    0x02    /* bInterval: 2 ms */    
};

const unsigned char usb_string_language[] = {4, 0x03, 0x09, 0x04};

const unsigned char usb_string_product[] = {16, 0x03, 'U', 0x00, 'S', 0x00, 'B', 0x00, 'l', 0x00, 'i', 0x00, 'n', 0x00, 'i', 0x00};
const unsigned char usb_string_manuf[] = {28, 0x03, 'w', 0x00, 'w', 0x00, 'w', 0x00, '.', 0x00, 'f', 0x00, 'i', 0x00, 's', 0x00, 'c', 0x00, 'h', 0x00, 'l', 0x00, '.', 0x00, 'd', 0x00, 'e', 0x00};

#endif